import psutil
from jadi import component

from aj.plugins.dashboard.api import Widget


@component(Widget)
class CPUWidget(Widget):
    id = 'cpu'
    name = _('CPU usage')
    template = '/dashboard:resources/partial/widgets/cpu.html'

    def __init__(self, context):
        Widget.__init__(self, context)

    def get_value(self, config):
        return [x / 100 for x in psutil.cpu_percent(interval=0, percpu=True)]



import psutil
import time
from jadi import component

from aj.plugins.dashboard.api import Widget


@component(Widget)
class UptimeWidget(Widget):
    id = 'uptime'
    name = _('Uptime')
    template = '/dashboard:resources/partial/widgets/uptime.html'

    def __init__(self, context):
        Widget.__init__(self, context)

    def get_value(self, config):
        return time.time() - psutil.boot_time()



import os
import subprocess
from jadi import component

from aj.plugins.dashboard.api import Widget


@component(Widget)
class LoadAverageWidget(Widget):
    id = 'loadavg'
    name = _('Load average')
    template = '/dashboard:resources/partial/widgets/loadavg.html'

    def __init__(self, context):
        Widget.__init__(self, context)

    def get_value(self, config):
        if os.path.exists('/proc/loadavg'):
            return [float(open('/proc/loadavg').read().split()[x]) for x in range(3)]
        else:
            tokens = subprocess.check_output(['uptime']).split()
            return [float(x.strip(',')) for x in tokens[-3:]]



from jadi import interface


@interface
class Widget(object):
    """
    Base interface for dashboard widgets.
    """
    id = None

    name = None
    """Display name"""

    template = None
    """Angular view template URL"""

    config_template = None
    """Configuration dialog template URL"""

    def __init__(self, context):
        self.context = context

    def get_value(self, config):
        """
        Override this to return the widget value for the given config dict.
        """
        raise NotImplementedError
